Name:           ceres-solver
Version:        2.1.0
Release:    1%{?dist}
Summary:        A non-linear least squares minimizer

License:        BSD

URL:            http://ceres-solver.org/
Source0:        http://%{name}.org/%{name}-%{version}.tar.gz

%global blaslib flexiblas
%global cmake_blas_flags -DBLA_VENDOR=FlexiBLAS

%ifarch ppc64le
%undefine _lto_cflags
%endif

BuildRequires:  cmake >= 2.8.0
BuildRequires:  gcc-c++
BuildRequires:  make

BuildRequires:  eigen3-static >= 3.2.1

BuildRequires:  suitesparse-devel >= 3.4.0-9

BuildRequires:  tbb-devel

BuildRequires:  %{blaslib}-devel
BuildRequires:  gflags-devel >= 2.2.1
BuildRequires:  glog-devel >= 0.3.1

%description

Ceres Solver is an open source C++ library for modeling and solving
large, complicated optimization problems. It is a feature rich, mature
and performant library which has been used in production at Google
since 2010. Notable use of Ceres Solver is for the image alignment in
Google Maps and for vehicle pose in Google Street View. Ceres Solver
can solve two kinds of problems.

  1. Non-linear Least Squares problems with bounds constraints.
  2. General unconstrained optimization problems.

Features include:

  - A friendly API: build your objective function one term at a time
  - Automatic and numeric differentiation
  - Robust loss functions
  - Local parameterizations
  - Threaded Jacobian evaluators and linear solvers
  - Trust region solvers with non-monotonic steps (Levenberg-Marquardt and
    Dogleg (Powell & Subspace))
  - Line search solvers (L-BFGS and Nonlinear CG)
  - Dense QR and Cholesky factorization (using Eigen) for small problems
  - Sparse Cholesky factorization (using SuiteSparse) for large sparse problems
  - Specialized solvers for bundle adjustment problems in computer vision
  - Iterative linear solvers for general sparse and bundle adjustment problems
  - Runs on Linux, Windows, Mac OS X, Android, and iOS


%package        devel
Summary:        A non-linear least squares minimizer
Requires:       %{name} = %{version}-%{release}
Requires:       eigen3-devel
Requires:       gflags-devel
Requires:       glog-devel
Requires:       suitesparse-devel

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%autosetup -p1

%build
%cmake \
  -DCXSPARSE_INCLUDE_DIR:PATH=%{_includedir}/suitesparse \
  %{cmake_blas_flags} \
  -DGFLAGS_INCLUDE_DIR=%{_includedir}
%cmake_build


%install
%cmake_install


%check
%ifarch aarch64 ppc64le s390x
%ctest || :
%else
%ctest
%endif




%files
%doc README.md
%license LICENSE
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/cmake/Ceres


%changelog
* Thu Apr 11 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.1.0-1
- initial build
